PyTorch implementation of GD-VAEs.

NOTE: The package is still being packaged for pip.  Please sign-up below for Google-Form for mailing list announcing soon this code release:
<https://forms.gle/mJSRRrqMo8CwFKRC7>

If you find these codes or methods helpful for your project, please cite: 

```
@article{lopez_atzberger_gd_vae_2022,
  title={GD-VAEs: Geometric Dynamic Variational Autoencoders for 
  Learning Non-linear Dynamics and Dimension Reductions},
  author={Ryan Lopez, Paul J. Atzberger},
  journal={arXiv:2206.05183},  
  month={June},
  year={2022},
  url={http://arxiv.org/abs/2206.05183}
}
```  

Source code and additional information for this package available at <https://github.com/gd-vae>
and <http://atzberger.org>.

